import logging
import requests


class BaseAdapter:

    PRICE_PRECISION = 4

    def __init__(self, config=None):
        self.logger = logging.getLogger(__name__)
        self.logger.setLevel(logging.INFO)
        self.config = config or {}

    def get_usd_btc_pair(self):
        resp = requests.get("https://api.coinmarketcap.com/v1/ticker/bitcoin/")
        return float(resp["price_usd"])

    def bundle_adapter_name(self, message):
        return f"{self.__class__.__name__}: {message}"

    def validate_response(self, response):
        if response.status_code != 200:
            self.logger.error(
                self.bundle_adapter_name(
                    f"Invalid HTTP status code: {response.status_code}"))
            return None
        response_json = response.json()
        return response_json

    def get_price(self):
        raise NotImplementedError



from .base import BaseAdapter
import requests


class HuobiAdapter(BaseAdapter):

    BASE_URL = "https://api.huobi.pro/market/detail/merged"

    def get_price(self):
        btc_steem_response = requests.get(
            self.BASE_URL, params={"symbol": "hivebtc"})
        btc_steem_response_json = self.validate_response(btc_steem_response)

        usd_btc_response = requests.get(
            self.BASE_URL, params={"symbol": "btcusdt"}
        )
        usd_btc_response_json = self.validate_response(usd_btc_response)

        if btc_steem_response_json and usd_btc_response_json:
            btc_steem_pair = btc_steem_response_json["tick"]["close"]
            usd_btc_pair = usd_btc_response_json["tick"]["close"]

            price = round(usd_btc_pair * btc_steem_pair, self.PRICE_PRECISION)
            self.logger.info(self.bundle_adapter_name(f'Price: {price}'))
            return price


from .base import BaseAdapter
import requests


class MxcAdapter(BaseAdapter):
    BASE_URL = "https://www.mxc.com/open/api/v2/market/ticker"

    def get_price(self):

        if not self.config.get("MXC_API_KEY"):
            raise ValueError(
                "You need to provide MXC_API_KEY environment variable.")

        hive_usdt_response = requests.get(
            self.BASE_URL,
            params={"api_key": self.config["MXC_API_KEY"], "symbol": "hive_usdt"})
        hive_usdt_response_json = self.validate_response(hive_usdt_response)

        if hive_usdt_response and hive_usdt_response_json:
            hive_usd_pair = hive_usdt_response_json["data"][0]["last"]

            price = round(float(hive_usd_pair), self.PRICE_PRECISION)
            self.logger.info(self.bundle_adapter_name(f'Price: {price}'))
            return price
